import { useAjax } from "@/Hook/useAjax"
import { getAppAccountConfig, tencentAdAccountDoAuth, tencentAdAccountToAuth } from "@/services/miniApp/adBack"
import { BetaSchemaForm, PageContainer, ProCard, ProForm, ProFormRadio, ProFormSelect, ProFormText } from "@ant-design/pro-components"
import { history, useModel } from "@umijs/max"
import { Button, Divider, message, Space } from "antd"
import { useEffect, useRef, useState } from "react"
import formConfig from "./formConfig"
import { searchToObj } from "@/utils"

function Auth() {
    let { getEnum } = useModel('global')
    let { initialState } = useModel("@@initialState")
    let [key, setKey] = useState<any>()
    let [isEdit, setIsEdit] = useState(false)
    let formRef = useRef()
    let TencentAdAccountToAuth = useAjax((params) => tencentAdAccountToAuth(params))//获取授权地址
    let TencentAdAccountDoAuth = useAjax((params) => tencentAdAccountDoAuth(params))//开始授权
    let GetAppAccountConfig = useAjax((params) => getAppAccountConfig(params))//获取回传配置
    // 获取广告回传列表
    useEffect(() => {
        // 授权回调
        if (history.location.search) {
            let obj = searchToObj(history.location.search)
            if (obj?.state && obj?.authorization_code) {
                TencentAdAccountDoAuth.run({
                    "state": obj.state,
                    "authorizationCode": obj.authorization_code,
                    "callbackPage": "https://testdistribution.zanxiangwl.com/miniApp/adBack"
                }).then(res => {
                    if (res.code === 200) {
                        message.success("授权成功")
                        history.push("/miniApp/adBack")
                    }
                })
            }
        }
        getConfig()
    }, [])
    //获取回传配置
    const getConfig = () => {
        GetAppAccountConfig.run({ appType: initialState?.selectApp?.appType, appId: initialState?.selectApp?.id })
    }
    // 授权
    const auth = () => {
        TencentAdAccountToAuth.run({
            appType: initialState?.selectApp?.appType,
            appId: initialState?.selectApp?.id,
            advertisingChannel: key,
            callbackPage: "https://testdistribution.zanxiangwl.com/miniApp/adBack"
        }).then(res => {
            if (res.code === 200) {
                window.open(res.data)
            }
        })
    }
    // submit
    const submit = async (values: any) => {
        // 遍历 firstBackRate 数组，并将 backRate 转换为字符串
        if (values.firstBackRate) {
            values.firstBackRate = values.firstBackRate.map((item: any) => {
                if (Array.isArray(item.backRate)) {
                    item.backRate = item.backRate.join(":"); // 转换数组为 'min:max' 字符串
                }
                return item;
            });
        }
        // 打印转换后的数据
        console.log("处理后的表单数据: ", values);
    }
    return <PageContainer
        tabList={getEnum("ADVERTISING_CHANNEL", "arr")?.map((item: { label: any; key: any }, index: number) => {
            if (index === 0 && !key) {
                setKey(item.key)
            }
            return { tab: item.label, key: item.key }
        })}
        tabProps={{
            type: 'card',
            hideAdd: true,
            onChange: (e) => setKey(e),
        }}
    >
        <ProCard direction="column" ghost gutter={8} >
            <ProCard
                bordered
                title="归因设置"
                actions={
                    <Space style={{ margin: 20 }}> <Button type="primary" onClick={auth}>授权</Button></Space>
                }
            >
                <ProForm
                    readonly={true}
                    submitter={false}
                    colProps={{ span: 2 }}
                    labelCol={{ span: 1 }}
                    layout="horizontal"
                >
                    {/* 数据源ID */}
                    <ProFormText label={"归因方式"} formItemProps={{ style: { marginBottom: 10 } }} />
                    <ProFormText label={"数据源类型"} formItemProps={{ style: { marginBottom: 10 } }} />
                    <ProFormText label={"数据源ID"} formItemProps={{ style: { marginBottom: 10 } }} />
                    {/* accountId */}
                    <ProFormText label={"已授权账号ID"} formItemProps={{ style: { marginBottom: 10 } }} />
                </ProForm>

            </ProCard>
            <ProCard
                bordered
                title="回传设置"
                tooltip="回传“下单”“付费”两个行为事件，直投小程序链路额外支持“注册”（纯新+染色回流用户进入小程序）事件回传。"
                actions={<Space style={{ margin: 20 }}>
                    {
                        !isEdit ? <>
                            <Button type="primary" onClick={() => { setIsEdit(true) }}>编辑</Button>
                            <Button>取消回传</Button>
                        </> : <>
                            <Button type="primary" onClick={() => { setIsEdit(true) }}>保存</Button>
                            <Button onClick={() => { setIsEdit(false) }}>取消</Button>
                        </>
                    }
                </Space>}
            >
                <ProForm
                    readonly={true}
                    formRef={formRef}
                    submitter={false}
                    colProps={{ span: 2 }}
                    labelCol={{ span: 2 }}
                    layout="horizontal"
                >
                    {/*  注册充值回传的最大间隔时间,回传类型,VIP回传策略,是否补单,单用户最大回传订单数,详情弹窗*/}
                    <ProFormText label={"注册充值回传的最大间隔时间"} formItemProps={{ style: { marginBottom: 10 } }} />
                    <ProFormRadio.Group label={"单用户最大回传订单数"} formItemProps={{ style: { marginBottom: 10 } }} />
                    <ProFormRadio.Group label={"回传类型"} formItemProps={{ style: { marginBottom: 10 } }} />
                    <ProFormSelect label={"VIP回传策略"} formItemProps={{ style: { marginBottom: 10 } }} />
                    <ProFormRadio.Group label={"是否补单"} formItemProps={{ style: { marginBottom: 10 } }} />
                </ProForm>
            </ProCard>
        </ProCard>
        {/* 回传配置 */}
        <BetaSchemaForm<any>
            title={"回传策略配置"}
            formRef={formRef}
            open={isEdit}
            onOpenChange={(b) => { !b && setIsEdit(b) }}
            layoutType={"ModalForm"}
            labelCol={{ span: 24 }}
            colProps={{ span: 8 }}
            grid={true}
            layout="vertical"
            onFinish={submit}
            columns={formConfig()}
            modalProps={{
                destroyOnClose: true
            }}
        />
    </PageContainer>
}

export default Auth